token

package
v0.0.0-...-26d136f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2025 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	ErrInvalidToken = fmt.Errorf("token is invalid")
	ErrExpiredToken = fmt.Errorf("token has expired")
)

Functions

This section is empty.

Types

type JWTMaker

type JWTMaker struct {
	// contains filtered or unexported fields
}

func (*JWTMaker) CreateToken

func (jwtMaker *JWTMaker) CreateToken(username string, duration time.Duration) (string, error)

func (*JWTMaker) VerifyToken

func (jwtMaker *JWTMaker) VerifyToken(token string) (*Payload, error)

type Maker

type Maker interface {
	// CreateToken creates a new token for a specific username and duration
	CreateToken(username string, duration time.Duration) (string, error)

	VerifyToken(token string) (*Payload, error)
}

func NewJWTMaker

func NewJWTMaker(secretKey string) (Maker, error)

func NewPasetoMaker

func NewPasetoMaker(symmetricKey string) (Maker, error)

type PasetoMaker

type PasetoMaker struct {
	// contains filtered or unexported fields
}

func (*PasetoMaker) CreateToken

func (maker *PasetoMaker) CreateToken(username string, duration time.Duration) (string, error)

func (*PasetoMaker) VerifyToken

func (maker *PasetoMaker) VerifyToken(token string) (*Payload, error)

type Payload

type Payload struct {
	ID        uuid.UUID `json:"id"`
	Username  string    `json:"username"`
	IssuedAt  time.Time `json:"issued_at"`
	ExpiredAt time.Time `json:"expired_at"`
}

func NewPayLoad

func NewPayLoad(username string, duration time.Duration) (*Payload, error)

New Payload create new payload wtih a specifig username and duration.

func (*Payload) GetAudience

func (payload *Payload) GetAudience() (jwt.ClaimStrings, error)

func (*Payload) GetExpirationTime

func (payload *Payload) GetExpirationTime() (*jwt.NumericDate, error)

实现 jwt.Claims 接口所需的方法

func (*Payload) GetIssuedAt

func (payload *Payload) GetIssuedAt() (*jwt.NumericDate, error)

func (*Payload) GetIssuer

func (payload *Payload) GetIssuer() (string, error)

func (*Payload) GetNotBefore

func (payload *Payload) GetNotBefore() (*jwt.NumericDate, error)

func (*Payload) GetSubject

func (payload *Payload) GetSubject() (string, error)

func (*Payload) Valid

func (payload *Payload) Valid() error

Valid checks if the token payload is valid or not

Jump to